feedgen.ext.podcast — python-feedgen 0.2.8 documentation

# python-feedgen 0.2.8 documentation

## feedgen.ext.podcast

Contents

# feedgen.ext.podcast

Extends the FeedGenerator to produce podcasts.

copyright: | 2013, Lars Kiesow <lkiesow@uos.de>
license: | FreeBSD and LGPL, see license.* for more details.

class `feedgen.ext.podcast.` `PodcastExtension`

  FeedGenerator extension for podcasts.

  `extend_rss`(rss_feed)

    Create an RSS feed xml structure containing all previously set fields.

    Returns: | Tuple containing the feed root element and the element tree.

  `itunes_author`(itunes_author=None)

    Get or set the itunes:author. The content of this tag is shown in the Artist column in iTunes. If the tag is not present, iTunes uses the contents of the <author> tag. If <itunes:author> is not present at the feed level, iTunes will use the contents of <managingEditor>.

    Parameters: | itunes_author – The author of the podcast.
    Returns: | The author of the podcast.

  `itunes_block`(itunes_block=None)

    Get or set the ITunes block attribute. Use this to prevent the entire podcast from appearing in the iTunes podcast directory.

    Parameters: | itunes_block – Block the podcast.
    Returns: | If the podcast is blocked.

  `itunes_category`(itunes_category=None, itunes_subcategory=None)

    Get or set the ITunes category which appears in the category column and in iTunes Store Browser.

    The (sub-)category has to be one from the values defined at http://www.apple.com/itunes/podcasts/specs.html#categories

    Parameters: | itunes_category – Category of the podcast. itunes_subcategory – Subcategory of the podcast.
    Returns: | Category data of the podcast.

  `itunes_complete`(itunes_complete=None)

    Get or set the itunes:complete value of the podcast. This tag can be used to indicate the completion of a podcast.

    If you populate this tag with “yes”, you are indicating that no more episodes will be added to the podcast. If the <itunes:complete> tag is present and has any other value (e.g. “no”), it will have no effect on the podcast.

    Parameters: | itunes_complete – If the podcast is complete.
    Returns: | If the podcast is complete.

  `itunes_explicit`(itunes_explicit=None)

    Get or the the itunes:explicit value of the podcast. This tag should be used to indicate whether your podcast contains explicit material. The three values for this tag are “yes”, “no”, and “clean”.

    If you populate this tag with “yes”, an “explicit” parental advisory graphic will appear next to your podcast artwork on the iTunes Store and in the Name column in iTunes. If the value is “clean”, the parental advisory type is considered Clean, meaning that no explicit language or adult content is included anywhere in the episodes, and a “clean” graphic will appear. If the explicit tag is present and has any other value (e.g., “no”), you see no indicator — blank is the default advisory type.

    Parameters: | itunes_explicit – If the podcast contains explicit material.
    Returns: | If the podcast contains explicit material.

  `itunes_image`(itunes_image=None)

    Get or set the image for the podcast. This tag specifies the artwork for your podcast. Put the URL to the image in the href attribute. iTunes prefers square .jpg images that are at least 1400x1400 pixels, which is different from what is specified for the standard RSS image tag. In order for a podcast to be eligible for an iTunes Store feature, the accompanying image must be at least 1400x1400 pixels.

    iTunes supports images in JPEG and PNG formats with an RGB color space (CMYK is not supported). The URL must end in ”.jpg” or ”.png”. If the <itunes:image> tag is not present, iTunes will use the contents of the RSS image tag.

    If you change your podcast’s image, also change the file’s name. iTunes may not change the image if it checks your feed and the image URL is the same. The server hosting your cover art image must allow HTTP head requests for iTS to be able to automatically update your cover art.

    Parameters: | itunes_image – Image of the podcast.
    Returns: | Image of the podcast.

  `itunes_new_feed_url`(itunes_new_feed_url=None)

    Get or set the new-feed-url property of the podcast. This tag allows you to change the URL where the podcast feed is located

    After adding the tag to your old feed, you should maintain the old feed for 48 hours before retiring it. At that point, iTunes will have updated the directory with the new feed URL.

    Parameters: | itunes_new_feed_url – New feed URL.
    Returns: | New feed URL.

  `itunes_owner`(name=None, email=None)

    Get or set the itunes:owner of the podcast. This tag contains information that will be used to contact the owner of the podcast for communication specifically about the podcast. It will not be publicly displayed.

    Parameters: | itunes_owner – The owner of the feed.
    Returns: | Data of the owner of the feed.

  `itunes_subtitle`(itunes_subtitle=None)

    Get or set the itunes:subtitle value for the podcast. The contents of this tag are shown in the Description column in iTunes. The subtitle displays best if it is only a few words long.

    Parameters: | itunes_subtitle – Subtitle of the podcast.
    Returns: | Subtitle of the podcast.

  `itunes_summary`(itunes_summary=None)

    Get or set the itunes:summary value for the podcast. The contents of this tag are shown in a separate window that appears when the “circled i” in the Description column is clicked. It also appears on the iTunes page for your podcast. This field can be up to 4000 characters. If <itunes:summary> is not included, the contents of the <description> tag are used.

    Parameters: | itunes_summary – Summary of the podcast.
    Returns: | Summary of the podcast.